import os, sys
if __name__ == "__main__":
    execfile(os.path.join(sys.path[0], "framework.py"))

from Testing import ZopeTestCase
from Products.plonetrackback.tests import PloneTrackbackTestCase
from Products import Five

from Products.plonetrackback.interfaces import \
     ITrackback, IStoredTrackback, ITrackbackInManager
from Products.plonetrackback.trackback import Trackback
#from Products.plonetrackback.trackbackin import TrackbackInManagerAnnotations


class TestTrackbackInManager(PloneTrackbackTestCase.PloneTrackbackTestCase):

    def afterSetUp(self):
        self.folder.invokeFactory("Document",
                                  id="test_page",
                                  title="Test Page")
        self.document = getattr(self.folder, "test_page")
        Five.zcml.load_config('configure_document.zcml')

    def testStoreAndRetrieve(self):
        tbim = ITrackbackInManager(self.document)
        # No trackback pings to start with
        self.failUnless(tbim.getTrackbacks() == [])
        # Create a trackback...
        tbdict = {  'title'      : 'Trackback Title'
                  , 'url'        : 'http://example.com/'
                  , 'excerpt'    : 'The excerpt of the post.'
                  , 'site_title' : 'Trackback Test Site'
                 }
        tb = Trackback(**tbdict)
        # Store the trackback
        tbim.storeTrackback(tb)
        tbs = tbim.getTrackbacks()
        self.failUnless( len(tbs) == 1 )
        tb0 = tbs[0]
        self.failUnless( IStoredTrackback.providedBy(tb0) )
        self.failUnless(tb0.getTitle() == tbdict['title'])
        self.failUnless(tb0.getURL() == tbdict['url'])
        self.failUnless(tb0.getExcerpt() == tbdict['excerpt'])
        self.failUnless(tb0.getSiteTitle() == tbdict['site_title'])


    def testStoreAndDelete(self):
        tbim = ITrackbackInManager(self.document)
        # No trackback pings to start with
        self.failUnless(tbim.getTrackbacks() == [])
        # Create some trackbacks
        tbdict1 = {  'title'      : 'Trackback Title1'
                   , 'url'        : 'http://example.com/'
                   , 'excerpt'    : 'The excerpt of the first post.'
                   , 'site_title' : 'Trackback Test Site'
                  }
        tbdict2 = {  'title'      : 'Trackback Title2'
                   , 'url'        : 'http://example.com/'
                   , 'excerpt'    : 'The excerpt of the second post.'
                   , 'site_title' : 'Trackback Test Site'
                  }
        tb1 = Trackback(**tbdict1)
        tb2 = Trackback(**tbdict2)
        # Store the trackbacks
        tbim.storeTrackback(tb1)
        tbim.storeTrackback(tb2)
        self.failUnless( len(tbim.getTrackbacks()) == 2 )
        # Find the first trackback
        tbid = None
        for each in tbim.getTrackbacks():
            if each.getTitle() == tbdict1['title']:
                tbid = each.getId()
                break
        # Delete the first trackback
        tbim.deleteTrackback(tbid)
        tbs = tbim.getTrackbacks()
        self.failUnless( len(tbs) == 1 )
        tb0 = tbs[0]
        self.failUnless(tb0.getTitle() == tbdict2['title'])
        self.failUnless(tb0.getURL() == tbdict2['url'])
        self.failUnless(tb0.getExcerpt() == tbdict2['excerpt'])
        self.failUnless(tb0.getSiteTitle() == tbdict2['site_title'])



def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestTrackbackInManager))
    return suite

if __name__ == '__main__':
    framework()
